package polly

  1. Overview
  2. Docs

polly

API

Library polly

  • Polly Module Polly provides access to the Linux epoll system call for monitoring a set of file descriptors for events that the client is interested in.