Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Polly.EventFDSourceThis module provides an interface to the eventfd(2) system call
create initval flags creates an evenfd with the given initial value and flags. See man evenfd(2).
test x y returns true, if and only if the intersection of the two sets is not empty. The common case is test set x where set is unknown and x is a singleton to check that x is contained in set.
to_string flags return a string representation of flags for debugging
Read the vaue of the eventfd. Block if it is zero (or trigger EAGAIN) and if non zero, reset to 0 if it is not a semaphore otherwise it decrements by 1.